@@ -20,7 +20,6 @@
 #include "beatline.h"
 #include <qcanvas.h>
 #include <qpainter.h>
-#include "beatlinedata.h"
 BeatLine::BeatLine(QCanvas* canvas,long _pos)
  : QCanvasLine(canvas)
 {
@@ -32,11 +31,7 @@ BeatLine::BeatLine(QCanvas* canvas,long _pos)
         handle=new QRect(0,0,0,0);
         removeHandle=new QRect(0,0,0,0);
         lockunlockHandle=new QRect(0,0,0,0);
-        midiNoteHandle=new QRect(0,0,0,0);
         sampleValueView=0;
-        drawHandles=1;
-        midiNote=-1;
-        editingMidi=0;
 }
 
 
@@ -51,7 +46,7 @@ BeatLine::~BeatLine()
 /*!
     \fn BeatLine::getBeatPos()
  */
-long BeatLine::getBeatPos() const
+long BeatLine::getBeatPos()
 {
     return beatPos;
 }
@@ -114,16 +109,25 @@ int BeatLine::rtti() const
 
 
 void BeatLine::drawShape( QPainter &p ){
+    QPointArray triangle(3);
+    triangle.setPoint(0,QPoint(x()-5,0));
+    triangle.setPoint(1,QPoint(x()+5,0));
+    triangle.setPoint(2,QPoint(x(),10));
+
+    QPointArray losange(4);
+    losange.setPoint(0,QPoint(x(),0));
+    losange.setPoint(1,QPoint(x()+5,5));
+    losange.setPoint(2,QPoint(x(),10));
+    losange.setPoint(3,QPoint(x()-5,5));
+
 
     lockunlockHandle->setRect(x()-8,20,16,16);
     if(!locked()){
         removeHandle->setRect(x()-8,canvas()->height()-17,16,16);
         handle->setRect(x()-8,canvas()->height()/2,16,16);
-        midiNoteHandle->setRect(0,0,0,0);
     }else{
         removeHandle->setRect(0,0,0,0);
         handle->setRect(0,0,0,0);
-        midiNoteHandle->setRect(x()-8,canvas()->height()-17,17,17);
     }
 
 
@@ -134,40 +138,31 @@ void BeatLine::drawShape( QPainter &p ){
     p.drawLine(x(),1,x(),canvas()->height()-1);
     if(!isBpmLine()){
         if(locked()){
+            //p.drawPolygon(losange);
+            //p.drawPixmap(x()-8,0,QPixmap(qembed_findImage("encrypted")));
             p.drawPixmap(x()-8,0,QPixmap(qembed_findImage("1downarrow")));
 
         }else{
+            //p.drawPolygon(triangle);
             p.drawPixmap(x()-8,0,QPixmap(qembed_findImage("1downarrow")));
         }
-        if(drawHandles){
-            if(!locked()){
-                p.drawPixmap(*handle,QPixmap(qembed_findImage("leftrightarrow")));
-                p.drawPixmap(*removeHandle,QPixmap(qembed_findImage("cancel")));
-            }
-            if(locked()){
-                p.drawPixmap(*lockunlockHandle,QPixmap(qembed_findImage("encrypted")));
-                if(getEditingMidi()){
-                    p.drawPixmap(*midiNoteHandle,QPixmap(qembed_findImage("kcmmidi-current")));
-                }else{
-                    if(midiNote==-1)    //unasigned
-                        p.drawPixmap(*midiNoteHandle,QPixmap(qembed_findImage("kcmmidi")));
-                    else
-                        p.drawPixmap(*midiNoteHandle,QPixmap(qembed_findImage("kcmmidi-assigned")));
-                }
-            }else{
-                p.drawPixmap(*lockunlockHandle,QPixmap(qembed_findImage("decrypted")));
-            }
+
+        if(!locked()){
+            p.drawPixmap(*handle,QPixmap(qembed_findImage("leftrightarrow")));
+            p.drawPixmap(*removeHandle,QPixmap(qembed_findImage("cancel")));
         }
+        if(locked()) p.drawPixmap(*lockunlockHandle,QPixmap(qembed_findImage("encrypted")));
+        else p.drawPixmap(*lockunlockHandle,QPixmap(qembed_findImage("decrypted")));
     }
     p.setRasterOp(oldROP);
 }
 
 QPointArray  BeatLine::areaPoints() const{
     QPointArray result(4);
-    result.setPoint(0,QPoint((int)x()-20,-1));
-    result.setPoint(1,QPoint((int)x()+20,-1));
-    result.setPoint(2,QPoint((int)x()+20,canvas()->height()));
-    result.setPoint(3,QPoint((int)x()-20,canvas()->height()));
+    result.setPoint(0,QPoint((int)x()-10,-1));
+    result.setPoint(1,QPoint((int)x()+10,-1));
+    result.setPoint(2,QPoint((int)x()+10,canvas()->height()));
+    result.setPoint(3,QPoint((int)x()-10,canvas()->height()));
     return result;
 }
 
@@ -243,86 +238,3 @@ QRect* BeatLine::getLockUnlockHandle()
 {
     return lockunlockHandle;
 }
-
-
-/*!
-    \fn BeatLine::setDrawHandles(int tf)
- */
-void BeatLine::setDrawHandles(int tf)
-{
-    drawHandles=tf;
-}
-
-bool BeatLine::operator<( const BeatLine bl)
-{
-    cout<<"operator < called\n";
-    return beatPos < bl.getBeatPos();
-}
-
-bool BeatLine::operator==( const BeatLine bl)
-{
-    return beatPos == bl.getBeatPos();
-}
-
-
-/*!
-    \fn BeatLine::getMidiNoteHandle()
- */
-QRect* BeatLine::getMidiNoteHandle()
-{
-    return midiNoteHandle;
-}
-
-
-
-/*!
-    \fn BeatLine::setMidiNote(int mn)
- */
-void BeatLine::setMidiNote(int mn)
-{
-    midiNote=mn;
-}
-
-
-int BeatLine::getEditingMidi() const
-{
-  return editingMidi;
-}
-
-
-void BeatLine::setEditingMidi(const int& theValue)
-{
-    editingMidi = theValue;
-    canvas()->setChanged(boundingRect());
-}
-
-
-/*!
-    \fn BeatLine::getMidiNote()
- */
-int BeatLine::getMidiNote()
-{
-    return midiNote;
-}
-
-
-/*!
-    \fn BeatLine::boundingRect () const
- */
-QRect BeatLine::boundingRect () const
-{
-    return QRect(x()-20,-1,40,canvas()->height()+1);
-}
-
-
-/*!
-    \fn BeatLine::getData()
- */
-beatline_data BeatLine::getData()
-{
-    beatline_data data;
-    data.locked=locked();
-    data.position=getBeatPos();
-    data.midiNote=getMidiNote();
-    return data;
-}
