@@ -20,13 +20,10 @@
 #ifndef DEFS_H
 #define DEFS_H
 #include <stdio.h>
-#include "iostream"
+#include <iostream.h>
 #include <cassert>
 #include <limits.h>
 #include <float.h>
-
-using std::cout;
-
 template <class T>
 inline void zap(T & x)
 {
@@ -42,8 +39,7 @@ inline void zaparr(T & x)
      delete [] x;
      x = NULL;
 }
-#define RELEASE_NO "0.6alpha"
-#define RELEASE_NAME "Freecycle 0.6alpha"
+static char* release="Freecycle v0.31alpha";
 static const int RTTI_BEATLINE=1001;
 static const int RTTI_BPMLINE=1002;
 static const int RTTI_LOOPMARKER=1003;
@@ -52,17 +48,6 @@ static const int RTTI_VALUELINE=1005;
 static const int RTTI_DRAWINGLINE=1006;
 static const int RTTI_POLYLINE=1007;
 static const int RTTI_SPLINELINE=1008;
-static const int RTTI_LOCKEDBEATRECT=1009;
-static const int RTTI_LADSPAVALUERECT=1010;
-static const int RTTI_KEYBOARDRECT=1011;
-static const int RTTI_PITCHSHIFTRECT=1012;
-
-
-static const double BEAT_DISTANCE_TRESHOLD=128;
-
-static const int MIDI_INPUT_EVENT=2000;
-static const int PLAY_POSITION_CHANGED_EVENT=2001;
-
 
 #endif
 
