@@ -24,8 +24,8 @@ EffectFrame::EffectFrame(LADSPAEffect* _eff, QWidget* parent,const char* name)
 {
     setBackgroundColor(red);
     effect=_eff;
-    if (!effect->wasPortInitDone()) effect->initControlPortsValues();
-    effect->setPortInitDone(TRUE);
+    effect->initControlPortsValues();
+
 
     portsBar=new QMenuBar(this);
     QPopupMenu * portsMenu = new QPopupMenu( this );
@@ -73,7 +73,7 @@ EffectFrame::EffectFrame(LADSPAEffect* _eff, QWidget* parent,const char* name)
 
 
     portsBar->show();
-    //portFrames.setAutoDelete(TRUE);
+    portFrames.setAutoDelete(TRUE);
     for (QPtrList<LADSPAPort>::Iterator it=effect->getControlInputPorts()->begin();
             it!=effect->getControlInputPorts()->end();++it){
             QString portName=(*it)->getPortName();
@@ -99,15 +99,6 @@ EffectFrame::EffectFrame(LADSPAEffect* _eff, QWidget* parent,const char* name)
                                 tempFrame,SLOT(polylinesToggled()));
             connect(splinesButton,SIGNAL(pressed()),
                     tempFrame,SLOT(splinesToggled()));
-            connect(this,SIGNAL(beatLinesChangedS(QValueList< beatline_data > )),
-                    tempFrame,SLOT(beatLinesChanged(QValueList< beatline_data > )));
-            connect(this,SIGNAL(lockedBeatLinesChangedS(QValueList< beatline_data > )),
-                    tempFrame,SLOT(lockedBeatLinesChanged(QValueList< beatline_data > )));
-            connect(this,SIGNAL(zoomRatioChangedS(long )),
-                    tempFrame,SLOT(setZoomRatio(long )));
-            connect(this,SIGNAL(applyPolicyChanged(int )),
-                    tempFrame,SLOT(setApplyPolicy(int )));
-            connect(this,SIGNAL(cropS(long,long)),tempFrame,SLOT(crop(long, long )));
         }else{
             int id=portsMenu->insertItem(portName);
             portsMenu->setItemEnabled(id,FALSE);
@@ -119,19 +110,6 @@ EffectFrame::EffectFrame(LADSPAEffect* _eff, QWidget* parent,const char* name)
     switchOnReleaseApplyPolicy();
 }
 
-EffectFrame::~EffectFrame()
-{
-  /*  
-    delete pointsButton;
-    delete linesButton;
-    delete polylinesButton;
-    delete splinesButton;
-    delete drawModeBG;
-    delete portsBar;
-    delete executeMenu;
-*/
-}
-
 void EffectFrame::apply(){
     emit(applyMe(effect));
 }
@@ -151,13 +129,16 @@ void EffectFrame::closeEvent( QCloseEvent* ce ){
      for (QPtrList<EffectPortFrame>::Iterator it=portFrames.begin();
             it!=portFrames.end();++it){
                 stack->removeWidget(*it);
-                (*it)->close(TRUE); //close and delete the frame
+                (*it)->close();
     }
-    portFrames.clear(); //delete the pointers to frames
+    //portFrames.clear();
     ce->accept();
 }
 
+EffectFrame::~EffectFrame()
+{
 
+}
 
 
 
@@ -166,7 +147,10 @@ void EffectFrame::closeEvent( QCloseEvent* ce ){
  */
 void EffectFrame::setZoomRatio(long _zr)
 {
-    emit(zoomRatioChangedS(_zr));
+    for (QPtrList<EffectPortFrame>::Iterator it=portFrames.begin();
+            it!=portFrames.end();++it){
+                (*it)->setZoomRatio(_zr);
+    }
 }
 
 void EffectFrame::visibleAreaChanged(long start_sample, long end_sample){
@@ -208,7 +192,10 @@ void EffectFrame::switchOnChangeApplyPolicy(){
  */
 void EffectFrame::setApplyPolicy(int ap)
 {
-    emit(applyPolicyChanged(ap));
+    for (QPtrList<EffectPortFrame>::Iterator it=portFrames.begin();
+            it!=portFrames.end();++it){
+                (*it)->setApplyPolicy(ap);
+    }
 }
 
 
@@ -243,81 +230,3 @@ void EffectFrame::changeDrawMode(EffectPortFrame::DrawMode dm)
         case EffectPortFrame::DRAW_MODE_SPLINES:{splinesButton->setOn(TRUE);break;}
     }
 }
-
-void EffectFrame::lockedBeatLinesChanged(QValueList <beatline_data> vl){
-    emit(lockedBeatLinesChangedS(vl));
-}
-void EffectFrame::beatLinesChanged(QValueList <beatline_data> vl){
-    emit(beatLinesChangedS(vl));
-}
-
-
-
-
-
-/*!
-    \fn EffectFrame::getLadspa()
- */
-LADSPAEffect* EffectFrame::getLadspa()
-{
-    return effect;
-}
-
-
-
-
-/*!
-    \fn EffectFrame::getPortFrame(int portNo)
- */
-EffectPortFrame* EffectFrame::getPortFrame(int portNo)
-{
-    for (QPtrList<EffectPortFrame>::Iterator it=portFrames.begin();
-         it!=portFrames.end();++it){
-             if((*it)->getPortNumber()==portNo) return (*it);
-         }
-}
-
-
-/*!
-    \fn EffectFrame::setSplineData(int port_no, QValueList<SplinePoint>)
- */
-void EffectFrame::setSplineData(int port_no, QValueList<SplinePoint> _spline)
-{
-    getPortFrame(port_no)->setSplineData(_spline);
-}
-
-
-/*!
-    \fn EffectFrame::setPolylineData(int port_no, QValueList<SortablePoint>)
- */
-void EffectFrame::setPolylineData(int port_no, QValueList<SortablePoint> _poly)
-{
-    getPortFrame(port_no)->setPolylineData(_poly);
-}
-
-
-/*!
-    \fn EffectFrame::updateDrawModeButton()
- */
-void EffectFrame::updateDrawModeButton()
-{
-    if(stack->visibleWidget()){
-        if (((EffectPortFrame*)stack->visibleWidget())->hasSpline())
-            changeDrawMode(EffectPortFrame::DRAW_MODE_SPLINES);
-        else if(((EffectPortFrame*)stack->visibleWidget())->hasPolyline())
-            changeDrawMode(EffectPortFrame::DRAW_MODE_POLYLINES);
-    }
-}
-
-
-/*!
-    \fn EffectFrame::reinitLADSPAValues()
- */
-void EffectFrame::reinitLADSPAValues()
-{
-    for (QPtrList<EffectPortFrame>::Iterator it=portFrames.begin();
-        it!=portFrames.end();++it){
-            (*it)->reinitLADSPAValues();
-            (*it)->update();
-    }
-}
