@@ -20,7 +20,7 @@
 #include "effectportframe.h"
 
 EffectPortFrame::EffectPortFrame(QString _name,LADSPAPort* _port,QWidget *parent, const char *name)
-    : QCanvasView(parent, name,Qt::WNoAutoErase)
+ : QCanvasView(parent, name)
 {
     enableClipper(TRUE);
     zoomRatio=1;
@@ -30,15 +30,10 @@ EffectPortFrame::EffectPortFrame(QString _name,LADSPAPort* _port,QWidget *parent
     linesCreated=FALSE;
     //setGeometry(((QVBox*)parent)->contentsRect());
     canvas=new ControllerCanvas(viewport());
-    canvas->setBackgroundColor(QColor(230,230,230));
-    canvas->setMaxValue(port->getUpperBound());
-    canvas->setMinValue(port->getLowerBound());
-    canvas->setStartX(contentsX());
-    canvas->setVisibleWidth(visibleWidth());
+    canvas->setBackgroundColor(lightGray);
     setResizePolicy(QScrollView::AutoOneFit);
     setCanvas(canvas);
     drawValueLines();
-    drawBeatlines();
     setVScrollBarMode(AlwaysOff);
     setHScrollBarMode(AlwaysOff);
     drawing=FALSE;
@@ -47,34 +42,23 @@ EffectPortFrame::EffectPortFrame(QString _name,LADSPAPort* _port,QWidget *parent
     drawMode=DRAW_MODE_POINTS;
     drawingLine=new DrawingLine(canvas);
     polyLine=new PolyLine(canvas);
-    polyLine->setMaxValue(port->getUpperBound());
-    polyLine->setMinValue(port->getLowerBound());
     polyLine->updateSize(canvas->size());
     spline=new SplineLine(canvas);
+    spline->updateSize(canvas->size());
     spline->setMaxValue(port->getUpperBound());
     spline->setMinValue(port->getLowerBound());
-    spline->updateSize(canvas->size());
-    ladspaValueView=new LADSPAValueView(canvas);
-    ladspaValueView->hide();
-
-    connect(this,SIGNAL(contentsMoving(int,int)), this,SLOT(contentsMoved(int,int)));
 }
 
 
 EffectPortFrame::~EffectPortFrame()
 {
-    delete ladspaValueView;    
-    delete drawingLine;
-    delete polyLine;
-    delete spline;
-    delete canvas;
+
 }
 
 void EffectPortFrame::raiseMe(){
     ((QWidgetStack*)parent())->raiseWidget(this);
-    canvas->resize((int)((double)port->getNbFrames()/(double)zoomRatio),visibleHeight());
+    canvas->resize(visibleWidth(),visibleHeight());
     drawValueLines();
-    drawBeatlines();
     polyLine->updateSize(canvas->size());
     spline->updateSize(canvas->size());
     update();
@@ -91,13 +75,9 @@ void EffectPortFrame::resizeEvent(QResizeEvent* ev)
     QCanvasView::resizeEvent(ev);
     canvas->resize((int)((double)port->getNbFrames()/(double)zoomRatio),
                     visibleHeight());
-    canvas->setStartX(contentsX());
-    canvas->setVisibleWidth(visibleWidth());
     drawValueLines();
-    drawBeatlines();
     polyLine->updateSize(canvas->size());
     spline->updateSize(canvas->size());
-
     canvas->update();
     //updateGeometry();
 }
@@ -106,14 +86,13 @@ void EffectPortFrame::drawValueLines(){
     float max=port->getUpperBound();
     float min=port->getLowerBound();
     float diff=max-min;
-    int count=0;
+
     if(!linesCreated){
         for (double i=0;i<port->getNbFrames();i+=1024){
                 ValueLine* line=new ValueLine(canvas,(long)i,(float*)port->getVOTPointer((int)i/1024));
                 int drawValue=(int)(visibleHeight()-((line->getValue()-min)*visibleHeight())/diff);
                 line->setPen(darkGray);
                 line->setPoints((int)(i/zoomRatio),drawValue,(int)(i/zoomRatio),visibleHeight());
-                line->setWidth(ceil(1024/zoomRatio));
                 line->show();
         }
         linesCreated=TRUE;
@@ -121,7 +100,6 @@ void EffectPortFrame::drawValueLines(){
         QCanvasItemList l=canvas->allItems();
         for (QCanvasItemList::Iterator it=l.begin(); it!=l.end(); ++it) {
             if((*it)->rtti()==RTTI_VALUELINE){
-                count++;
                 ValueLine* templine=(ValueLine*)(*it);
                 if (templine->isVisible()){
                     int drawValue=
@@ -130,15 +108,26 @@ void EffectPortFrame::drawValueLines(){
                                                         drawValue,
                                                     templine->getSamplePos()/zoomRatio,
                                                     visibleHeight());
-                    templine->setWidth(ceil(1024/zoomRatio));
                 }
             }
         }
     }
     canvas->update();
-    //cout<<"VALUELINES_NB= "<<count<<endl;
 }
 
+/*!
+    \fn EffectPortFrame::repaintEvent(QPaintEvent*)
+ */
+void EffectPortFrame::paintEvent(QPaintEvent*)
+{
+    //canvas->resize(visibleWidth(),visibleHeight());
+    //drawValueLines();
+    /*
+    canvas->resize((int)(port->getNbFrames()/zoomRatio),
+                                            c_height);
+    */
+    //canvas->update();
+}
 
 void EffectPortFrame::closeEvent( QCloseEvent* ce ){
 
@@ -157,10 +146,7 @@ void EffectPortFrame::setZoomRatio(long _zr)
     canvas->resize((int)((double)port->getNbFrames()/(double)zoomRatio),visibleHeight());
     cout<<"Effect frame canvas resized\n";
     drawValueLines();
-    drawBeatlines();
-    polyLine->setZoomRatio(zoomRatio);
     polyLine->updateSize(canvas->size());
-    spline->setZoomRatio(zoomRatio);
     spline->updateSize(canvas->size());
     canvas->update();
 }
@@ -185,27 +171,14 @@ ControllerCanvas* EffectPortFrame::getCanvas()
 
 void EffectPortFrame::contentsMousePressEvent( QMouseEvent * mouseEvent){
     QPoint pos=mouseEvent->pos();
-    ladspaValueView->setX(pos.x()+10);
-    ladspaValueView->setY(pos.y());
-    ladspaValueView->setValue(yPosToVal(pos.y()));
-    ladspaValueView->show();
     pos.setX(pos.x()<contentsX()?
             contentsX():pos.x()>contentsX()+width()?contentsX()+width():pos.x());
-    //magnet selection
-    long sample_pos=pos.x()*zoomRatio,temp_sample_pos=0;
-    int temp_pos_x=0;
-    this->getNearestLinePos(pos,temp_sample_pos,temp_pos_x);
-    if(pos.x()!=temp_pos_x && fabs(pos.x()-temp_pos_x)<3){
-        sample_pos=temp_sample_pos;
-        pos.setX(temp_pos_x);
-    }
-    //end magnet selection
     if(drawMode==DRAW_MODE_LINES){
         if (mouseEvent->button()==LeftButton){
             drawingLine->setStartPoint(pos.x(),pos.y());
             drawingLine->setEndPoint(pos.x(),pos.y());
-            drawingLine->setStartSample(sample_pos);
-            drawingLine->setEndSample(sample_pos);
+            drawingLine->setStartSample(pos.x()*zoomRatio);
+            drawingLine->setEndSample(pos.x()*zoomRatio);
             drawingLine->setStartValue(yPosToVal(pos.y()));
             drawingLine->show();
             canvas->update();
@@ -213,7 +186,7 @@ void EffectPortFrame::contentsMousePressEvent( QMouseEvent * mouseEvent){
         }
     }else if(drawMode==DRAW_MODE_POLYLINES){
         if (mouseEvent->button()==LeftButton){
-            polyLine->addPoint(pos,sample_pos,yPosToVal(pos.y()));
+            polyLine->addPoint(pos,pos.x()*zoomRatio,yPosToVal(pos.y()));
             polyLine->show();
             canvas->update();
             drawing=TRUE;
@@ -226,7 +199,7 @@ void EffectPortFrame::contentsMousePressEvent( QMouseEvent * mouseEvent){
         }
     }else if(drawMode==DRAW_MODE_SPLINES){
         if (mouseEvent->button()==LeftButton){
-            spline->addPoint(pos,sample_pos,yPosToVal(pos.y()));
+            spline->addPoint(pos,pos.x()*zoomRatio,yPosToVal(pos.y()));
             spline->show();
             canvas->update();
             drawing=TRUE;
@@ -255,36 +228,22 @@ void EffectPortFrame::contentsMousePressEvent( QMouseEvent * mouseEvent){
 
 void EffectPortFrame::contentsMouseMoveEvent( QMouseEvent * mouseEvent){
     QPoint pos=mouseEvent->pos();
-    ladspaValueView->setX(pos.x()+10);
-    ladspaValueView->setY(pos.y());
-    ladspaValueView->setValue(yPosToVal(pos.y()));
     pos.setX(pos.x()<contentsX()?
             contentsX():pos.x()>contentsX()+width()?contentsX()+width():pos.x());
     pos.setY(pos.y()<0?
             0:pos.y()>contentsHeight()?contentsHeight():pos.y());
-
-    //magnet selection
-    long sample_pos=pos.x()*zoomRatio,temp_sample_pos=0;
-    int temp_pos_x=0;
-    this->getNearestLinePos(pos,temp_sample_pos,temp_pos_x);
-    if(pos.x()!=temp_pos_x && fabs(pos.x()-temp_pos_x)<3){
-        sample_pos=temp_sample_pos;
-        pos.setX(temp_pos_x);
-    }
-    //end magnet selection
-
     if(drawMode==DRAW_MODE_LINES){
         if(drawing){
             drawingLine->setEndPoint(pos.x(),pos.y());
-            drawingLine->setEndSample(sample_pos);
+            drawingLine->setEndSample(pos.x()*zoomRatio);
             drawingLine->setEndValue(yPosToVal(pos.y()));
             canvas->update();
         }
     }else if(drawMode==DRAW_MODE_POLYLINES){
-        polyLine->moveSelectedPoint(pos,sample_pos,yPosToVal(pos.y()));
+        polyLine->moveSelectedPoint(pos,pos.x()*zoomRatio,yPosToVal(pos.y()));
         canvas->update();
     }else if(drawMode==DRAW_MODE_SPLINES){
-        spline->moveSelectedPoint(pos,sample_pos,yPosToVal(pos.y()));
+        spline->moveSelectedPoint(pos,pos.x()*zoomRatio,yPosToVal(pos.y()));
         canvas->update();
     }else if(drawMode==DRAW_MODE_POINTS){
         if(mouseEvent->state()==LeftButton ||mouseEvent->state()==RightButton){
@@ -304,8 +263,6 @@ void EffectPortFrame::contentsMouseMoveEvent( QMouseEvent * mouseEvent){
 }
 
 void EffectPortFrame::contentsMouseReleaseEvent( QMouseEvent * mouseEvent){
-    ladspaValueView->hide();
-    canvas->update();
     QPoint pos=mouseEvent->pos();
     pos.setX(pos.x()<contentsX()?
             contentsX():pos.x()>contentsX()+width()?contentsX()+width():pos.x());
@@ -322,7 +279,6 @@ void EffectPortFrame::contentsMouseReleaseEvent( QMouseEvent * mouseEvent){
                                 int y=drawingLine->getYAtX(temp->startPoint().x());
                                 temp->setPoints(temp->startPoint().x(),y,
                                                                 temp->endPoint().x(),visibleHeight());
-                                temp->setWidth(ceil(1024/zoomRatio));
                                 if (temp->getSamplePos()<update_interval.start_sample) {
                                     update_interval.start_sample=temp->getSamplePos();
                                 }
@@ -371,7 +327,6 @@ void EffectPortFrame::contentsMouseReleaseEvent( QMouseEvent * mouseEvent){
 
                             *(temp->getValuePointer())=controlerValue;
                             temp->setPoints(temp->startPoint().x(),y,temp->endPoint().x(),visibleHeight());
-                            temp->setWidth(ceil(1024/zoomRatio));
                             if (temp->getSamplePos()<update_interval.start_sample) {
                                 update_interval.start_sample=temp->getSamplePos();
                             }
@@ -437,7 +392,6 @@ EffectPortFrame::interval EffectPortFrame::updateValueAtPos(QPoint pos,bool left
                         ValueLine* temp=(ValueLine*)(*it);
                         *(temp->getValuePointer())=controlerValue;
                         temp->setPoints(temp->startPoint().x(),y,temp->endPoint().x(),visibleHeight());
-                        temp->setWidth(ceil(1024/zoomRatio));
                         if (temp->getSamplePos()<intdown) {intdown=temp->getSamplePos();}
                         if (temp->getSamplePos()>intup) {intup=temp->getSamplePos();}
                     }
@@ -531,254 +485,3 @@ EffectPortFrame::DrawMode EffectPortFrame::getDrawMode()
 {
     return drawMode;
 }
-
-
-/*!
-    \fn EffectPortFrame::beatLinesChanged(QValueList <beatline_data> beatlines)
- */
-void EffectPortFrame::beatLinesChanged(QValueList <beatline_data> _beatlines)
-{
-    beatlines=_beatlines;
-    drawBeatlines();
-    canvas->update();
-}
-
-
-/*!
-    \fn EffectPortFrame::lockedBeatLinesChanged(QValueList <beatline_data> beatlines)
- */
-void EffectPortFrame::lockedBeatLinesChanged(QValueList <beatline_data> _beatlines)
-{
-    lockedBeatlines=_beatlines;
-    drawBeatlines();
-    canvas->update();
-}
-
-
-/*!
-    \fn EffectPortFrame::drawBeatlines()
- */
-void EffectPortFrame::drawBeatlines()
-{
-    removeBeatlines();
-    /*
-    if(beatlines.count()!=0){
-        for (int i=0;i<beatlines.count();i++){
-            BeatLine* line=new BeatLine(canvas,beatlines[i]);
-            line->setPen(green);
-            int x=beatlines[i]/zoomRatio;
-            line->setPoints(x,0,x,visibleHeight());
-            line->show();
-        }
-    }
-    */
-    cout<<"Drawing "<<lockedBeatlines.count()<<" locked beatlines\n";
-    if(lockedBeatlines.count()!=0){
-        for (int i=0;i<lockedBeatlines.count();i++){
-            BeatLine* line=new BeatLine(canvas,lockedBeatlines[i].position);
-            line->lock();
-            line->setZ(10);
-            line->setDrawHandles(0);
-            line->setX(line->getBeatPos() / zoomRatio);
-            line->setPen(green);
-            int x=lockedBeatlines[i].position/zoomRatio;
-            line->setPoints(x,0,x,visibleHeight());
-            line->show();
-        }
-    }
-}
-
-
-/*!
-    \fn EffectPortFrame::removeBeatlines()
- */
-void EffectPortFrame::removeBeatlines()
-{
-    QCanvasItemList items=canvas->allItems();
-    if(!items.isEmpty()){
-        QCanvasItemList::iterator it;
-        for ( it = items.begin(); it != items.end(); ++it ){
-            if((*it)->rtti()==RTTI_BEATLINE){
-                (*it)->hide();
-                delete (*it);
-            }
-        }
-    }
-}
-
-/*!
-    \fn EffectPortFrame::getNearestLinePos(QPoint)
- */
-void EffectPortFrame::getNearestLinePos(QPoint pos,long& sample_pos,int& x)
-{
-    QCanvasItemList colisions=canvas->collisions(pos);
-    if(!colisions.isEmpty()){
-        QCanvasItemList::iterator it;
-        for ( it = colisions.begin(); it != colisions.end(); ++it ){
-            if((*it)->rtti()==RTTI_BEATLINE){
-                BeatLine* temp=(BeatLine*)(*it);
-                x=temp->x();
-                sample_pos=temp->getBeatPos();
-                    //cout<<"x: "<<x<<" sample_pos: "<<sample_pos<<endl;
-            }
-        }
-    }
-}
-
-
-
-
-
-/*!
-    \fn EffectPortFrame::getPortNumber()
- */
-int EffectPortFrame::getPortNumber()
-{
-    return port->getPortNumber();
-}
-
-
-/*!
-    \fn EffectPortFrame::hasPolyline()
- */
-bool EffectPortFrame::hasPolyline()
-{
-    return (polyLine && polyLine->isVisible() && polyLine->count()>0);
-}
-
-
-/*!
-    \fn EffectPortFrame::hasSpline()
- */
-bool EffectPortFrame::hasSpline()
-{
-    return (spline && spline->isVisible() && spline->count()>0);
-}
-
-
-/*!
-    \fn EffectPortFrame::getPolyline()
- */
-PolyLine* EffectPortFrame::getPolyline()
-{
-    return polyLine;
-}
-
-
-/*!
-    \fn EffectPortFrame::getSpline()
- */
-SplineLine* EffectPortFrame::getSpline()
-{
-    return spline;
-}
-
-
-/*!
-    \fn EffectPortFrame::setPolylineData(QValueList<SortablePoint>)
- */
-void EffectPortFrame::setPolylineData(QValueList<SortablePoint> points)
-{
-    drawMode=DRAW_MODE_POLYLINES;
-    for (int i=0;i<points.count();i++){
-        points[i].setX(points[i].getSamplePos()/zoomRatio);
-        points[i].setY(valToYPos(points[i].getValue()));
-    }
-    polyLine->setSortablePoints(points);
-    polyLine->show();
-}
-
-
-/*!
-    \fn EffectPortFrame::setSplineData(QValueList<SplinePoint>)
- */
-void EffectPortFrame::setSplineData(QValueList<SplinePoint> points)
-{
-    drawMode=DRAW_MODE_SPLINES;
-    for (int i=0;i<points.count();i++){
-        points[i].setX(points[i].getSamplePos()/zoomRatio);
-        points[i].setY(valToYPos(points[i].getValue()));
-        points[i].cp1.setX(points[i].cp1.getSamplePos()/zoomRatio);
-        points[i].cp1.setY(valToYPos(points[i].cp1.getValue()));
-        points[i].cp2.setX(points[i].cp2.getSamplePos()/zoomRatio);
-        points[i].cp2.setY(valToYPos(points[i].cp2.getValue()));
-    }
-    spline->setSplinePoints(points);
-    spline->show();
-}
-
-
-/*!
-    \fn EffectPortFrame::valToYPos(float val)
- */
-int EffectPortFrame::valToYPos(float val)
-{
-    float max=port->getUpperBound();
-    float min=port->getLowerBound();
-    return int(MyMath::linear_regression(min,max,visibleHeight(),0,val));
-}
-
-
-/*!
-    \fn EffectPortFrame::reinitLADSPAValues()
- */
-void EffectPortFrame::reinitLADSPAValues()
-{
-    cout<<"reiniting ladspa control values\n";
-    port->initControlValues();
-    QCanvasItemList l=canvas->allItems();
-    for (QCanvasItemList::Iterator it=l.begin(); it!=l.end(); ++it) {
-        if((*it)->rtti()==RTTI_VALUELINE){
-            (*it)->hide();
-            delete (*it);
-        }
-    }
-    linesCreated=FALSE;
-    drawValueLines();
-    drawBeatlines();
-    spline->clear();
-    polyLine->clear();
-    canvas->setAllChanged();
-    canvas->update();
-}
-
-
-
-
-/*!
-    \fn EffectPortFrame::contentsMoved(int x, int y)
- */
-void EffectPortFrame::contentsMoved(int x, int y)
-{
-    canvas->setStartX(x);
-    canvas->setVisibleWidth(visibleWidth());
-    canvas->setAllChanged();
-    canvas->update();
-}
-
-
-/*!
-    \fn EffectPortFrame::crop(long start, long end)
- */
-void EffectPortFrame::crop(long start, long end)
-{
-    cout<<"cropping port frame\n";
-    if (hasPolyline()) polyLine->crop(start,end);
-    if (hasSpline()) spline->crop(start,end);
-    long rest=1024-(start%1024);
-    port->crop(start,end);
-    QCanvasItemList l=canvas->allItems();
-    for (QCanvasItemList::Iterator it=l.begin(); it!=l.end(); ++it) {
-            if((*it)->rtti()==RTTI_VALUELINE){
-                ValueLine* templine=(ValueLine*)(*it);
-                if(templine->getSamplePos()<start || templine->getSamplePos()>=end){
-                    templine->hide();
-                    delete templine;
-                }else{
-                    templine->setSamplePos(templine->getSamplePos()-start-rest);
-                    templine->setValuePointer(port->getVOTPointer((int)(templine->getSamplePos()/1024)));
-                }
-            }
-    }
-    drawValueLines();
-}
