@@ -21,6 +21,9 @@
 #define ENVELOPEDATA_H
 
 #include <qdragobject.h>
+#include "mymath.h"
+#include "defs.h"
+
 
 /**
 @author Predrag Viceic
@@ -29,10 +32,45 @@ class EnvelopeData : public QTextDrag
 {
 Q_OBJECT
 public:
+    enum mode{FIT_TO_DURATION,FIT_TO_DURATION_CONTINUE,
+                            FIT_TO_SAMPLES, STRETCH_TO_SAMPLES, STRETCH_IF_LONGER,AUTO};
     EnvelopeData(const QString & text,QWidget * dragSource = 0, const char * name = 0);
-
+    EnvelopeData(QWidget * dragSource = 0, const char * name = 0 );
     ~EnvelopeData();
+    QString toString();
+    float getEnvAt(float x,float dt);
+    mode getMode();
+    float getDuration();
+    void setData(QString envDataS);
+    void setReleaseCy(float ry);
+    void setAttack(float a);
+    void setAttackCx(float ax);
+    void setAttackCy(float ay);
+    void setDecay(float a);
+    void setDecayCx(float dx);
+    void setDecayCy(float dy);
+    void setHold(float a);
+    void setRelease(float a);
+    void setReleaseCx(float rx);
+    void setSustain(float a);
+    int isEnabled();
+    void setEnabled(int e);
 
+
+    float attack;
+    float release;
+    float decay;
+    float hold;
+    float sustain;
+    float env_duration;
+    float env_resolution;
+    mode env_mode;
+    MyMath::FPoint2D attackC;
+    MyMath::FPoint2D decayC;
+    MyMath::FPoint2D releaseC;
+
+protected:
+    int enabled;
 };
 
 #endif
