@@ -23,7 +23,6 @@ LADSPAEffects::LADSPAEffects(QObject *parent, const char *name)
  : QObject(parent, name)
 {
     QPtrList<LADSPAEffect> availableLadspaEffects;
-    currentEffect=0;
 }
 
 
@@ -81,7 +80,7 @@ QPtrList <LADSPAEffect>* LADSPAEffects::getEffects()
 /*!
     \fn LADSPAEffects::getEffect(int)
  */
-LADSPAEffect* LADSPAEffects::getEffect(uint uniqueId)
+LADSPAEffect* LADSPAEffects::getEffect(int uniqueId)
 {
     for (QPtrList<LADSPAEffect>::Iterator it = getEffects()->begin();
             it!=getEffects()->end();++it){
@@ -101,22 +100,3 @@ void LADSPAEffects::setNbFrames(long nbf)
         (*it)->setNbFrames(nbf);
     }
 }
-
-
-
-/*!
-    \fn LADSPAEffects::getCurrent()
- */
-LADSPAEffect* LADSPAEffects::getCurrent()
-{
-    return currentEffect;
-}
-
-
-/*!
-    \fn LADSPAEffects::setCurrent(LADSPAEffect* eff)
- */
-void LADSPAEffects::setCurrent(LADSPAEffect* eff)
-{
-    currentEffect=eff;
-}
