@@ -26,9 +26,6 @@
 #include <limits.h>
 #include <float.h>
 #include <iostream.h>
-#include <math.h>
-#include "defs.h"
-
 /**
 @author Predrag Viceic
 */
@@ -62,12 +59,7 @@ public:
     int getConnectionMethod();
     int getConnectionMethodDouble();
     enum ConnectionMethod
-    {CONNECTION_METHOD_LR,CONNECTION_METHOD_L,CONNECTION_METHOD_R,CONNECTION_METHOD_ZERO};
-    void setConnectionMethodDouble(ConnectionMethod m);
-    void setConnectionMethod(ConnectionMethod m);
-    void initControlValues(QValueList<float> vals);
-    QValueList<float> getPortControlValues();
-
+        {CONNECTION_METHOD_LR,CONNECTION_METHOD_L,CONNECTION_METHOD_R,CONNECTION_METHOD_ZERO};
 private:
     LADSPA_PortDescriptor descriptor;
     LADSPA_PortRangeHint hint;
@@ -81,12 +73,9 @@ protected:
     long nbFrames;
     int connectionMethod;
     int connectionMethodDouble;
-    int nbValues;
 public slots:
     void setConnectionMethod(const QString&);
     void setConnectionMethodDouble(const QString&);
-    void crop(long start, long end);
-    void insert(long start, long amount);
 };
 
 #endif
