@@ -22,25 +22,32 @@
 #include "freecycle.h"
 #include "ueberstyle.h"
 #include "pics/icons.h"
+#include "defs.h"
 
 int main( int argc, char ** argv ) {
     QApplication a( argc, argv );
 
     for (int i=0;i<argc;i++){
-        if(QString(argv[i]).contains("ueber",FALSE)){
+        if(QString(argv[i]).contains("--ueber",FALSE)){
             QApplication::setStyle( new UeberStyle() );
         }
     }
 
+    QString filename="";
+    if(argc>1 && !QString(argv[argc-1]).contains("--")){
+        filename=QString(argv[argc-1]);
+    }
+
 
     //QSplashScreen *splash = new QSplashScreen(QPixmap(qembed_findImage("freecycle-splash")));
     //splash->show();
     Freecycle * mw = new Freecycle();
-    mw->setCaption( "Freecycle v0.21alpha" );
+    mw->setCaption( release );
     mw->show();
     //sleep(2);
     //splash->finish( mw );
     //delete splash;
     a.connect( &a, SIGNAL(lastWindowClosed()), &a, SLOT(quit()) );
+    if(!filename.isEmpty()) mw->load(filename);
     return a.exec();
 }
