@@ -39,6 +39,10 @@ SoundManager::SoundManager():SoundHolder(),FFTHolder()
         inversionBand=FALSE;
         playingBandOnly=FALSE;
         substractSpectralMean=TRUE;
+        beatLines.clear();
+        lockedBeatLines.clear();
+        envelopeData=0;
+        envelopeArray=0;
 }
 
 
@@ -90,10 +94,11 @@ QMemArray<long> SoundManager::analyse_freq_domain(const double treshold,
 
     if(!hirestemp_subband_energies){
                     hirestemp_subband_energies=
-                        compute_subband_energies(subband_number,hirestemp_fft_width,hirestemp_fft_advance,
-                                                                                                                hirestemp_padding,0,getFrames(),
-                                                                                                                hirestemp_startfreq,hirestemp_endfreq,
-                                                                                                                hirestemp_fftMinima,hirestemp_fftMaxima);
+                        compute_subband_energies(subband_number,hirestemp_fft_width,
+                                            hirestemp_fft_advance,
+                                            hirestemp_padding,0,getFrames(),
+                                            hirestemp_startfreq,hirestemp_endfreq,
+                                            hirestemp_fftMinima,hirestemp_fftMaxima,ORIGINAL_WAVE);
     }
 
     double* average_energy=new double[subband_number];
@@ -102,7 +107,7 @@ QMemArray<long> SoundManager::analyse_freq_domain(const double treshold,
     //double manual_treshold=linear_regression(0.0,20.0,2.0,5.0,treshold);
     //double manual_treshold=MyMath::linear_regression(0.0,20.0,0.05,1,treshold);
     double manual_treshold=
-                MyMath::linear_regression(1.0,20.0,0,0.8,treshold);
+                MyMath::linear_regression(1.0,20.0,0,1.01,treshold);
     if(foundBeats.size()==0){
         cout<<"Recomputing beats in frequency domain..\n";
         for (int i=start_sample;i<end_sample-hirestemp_fft_advance;i+=hirestemp_fft_advance){
@@ -159,7 +164,7 @@ QMemArray<long> SoundManager::analyse_freq_domain(const double treshold,
                             tempbeats[tempbeats.size()-1].band=k;
                             tempbeats[tempbeats.size()-1].instant_energy=temp_instant;
 
-                            tempbeats[tempbeats.size()-1].energy_at_pos=getLeftChannel()[i];
+                            tempbeats[tempbeats.size()-1].energy_at_pos=getLeftChannel(ORIGINAL_WAVE)[i];
 
                             /*
                             tempbeats[tempbeats.size()-1].min_amplitude=min_amplitude;
@@ -299,11 +304,11 @@ QMemArray<long> SoundManager::analyse_freq_domain(const double treshold,
         float* lchannel=0;
         float* rchannel=0;
          if(derivateSignal){
-            lchannel=exportDerivatedLeftBuffer(0,getFrames());
-            rchannel=exportDerivatedRightBuffer(0,getFrames());
+             lchannel=exportDerivatedLeftBuffer(0,getFrames(),ORIGINAL_WAVE);
+             rchannel=exportDerivatedRightBuffer(0,getFrames(),ORIGINAL_WAVE);
         }else{
-            lchannel=getLeftChannel();
-            rchannel=getRightChannel();
+            lchannel=getLeftChannel(ORIGINAL_WAVE);
+            rchannel=getRightChannel(ORIGINAL_WAVE);
         }
 
         for (k = 0; k < frames / overlap_size; k++) {
@@ -361,7 +366,7 @@ QMemArray<long> SoundManager::analyse_time_domain(const double treshold,
         tempbeats[0].instant_energy=1;
         tempbeats[0].energy_at_pos=1;
         double manual_treshold=
-                MyMath::linear_regression(1.0,20.0,0,0.8,treshold);
+                MyMath::linear_regression(1.0,20.0,0,1.01,treshold);
 
 
 
@@ -371,14 +376,14 @@ QMemArray<long> SoundManager::analyse_time_domain(const double treshold,
         float* lchannel=0;
         float* rchannel=0;
         if(derivateSignal){
-            lchannel=exportDerivatedLeftBuffer(0,getFrames());
-            rchannel=exportDerivatedRightBuffer(0,getFrames());
+            lchannel=exportDerivatedLeftBuffer(0,getFrames(),ORIGINAL_WAVE);
+            rchannel=exportDerivatedRightBuffer(0,getFrames(),ORIGINAL_WAVE);
         }else{
             //lchannel=exportLeftBuffer(0,getFrames());
             //rchannel=exportRightBuffer(0,getFrames());
 
-            lchannel=getLeftChannel();
-            rchannel=getRightChannel();
+            lchannel=getLeftChannel(ORIGINAL_WAVE);
+            rchannel=getRightChannel(ORIGINAL_WAVE);
         }
 
         //std::cout<<"window: "<<window<<" treshold: "<<treshold<<"\n";
@@ -487,18 +492,18 @@ QMemArray<long> SoundManager::analyse_time_domain(const double treshold,
                             float right_half_energy=0;
                             //find absolute minima and maxima
                             for (int count=i;count<i+amp_domain_instant_energy_buffersize;count++){
-                                if(fabs(getLeftChannel()[count]) <=min_amplitude){
-                                    min_amplitude=fabs(getLeftChannel()[count]);
+                                if(fabs(getLeftChannel(ORIGINAL_WAVE)[count]) <=min_amplitude){
+                                    min_amplitude=fabs(getLeftChannel(ORIGINAL_WAVE)[count]);
                                     min_pos=count;
                                 }
-                                if(fabs(getLeftChannel()[count]) >=max_amplitude){
-                                    max_amplitude=fabs(getLeftChannel()[count]);
+                                if(fabs(getLeftChannel(ORIGINAL_WAVE)[count]) >=max_amplitude){
+                                    max_amplitude=fabs(getLeftChannel(ORIGINAL_WAVE)[count]);
                                     max_pos=count;
                                 }
                                 if(count<i+amp_domain_instant_energy_buffersize/2){
-                                    left_half_energy+=fabs(getLeftChannel()[count]);
+                                    left_half_energy+=fabs(getLeftChannel(ORIGINAL_WAVE)[count]);
                                 }else{
-                                    right_half_energy+=fabs(getLeftChannel()[count]);
+                                    right_half_energy+=fabs(getLeftChannel(ORIGINAL_WAVE)[count]);
                                 }
                             }
                             //end find absolute minima and maxima
@@ -506,7 +511,7 @@ QMemArray<long> SoundManager::analyse_time_domain(const double treshold,
                             tempbeats[tempbeats.size()-1].sample_pos=pos;
                             tempbeats[tempbeats.size()-1].band=0;
                             tempbeats[tempbeats.size()-1].instant_energy=currentInstantEnergy;
-                            tempbeats[tempbeats.size()-1].energy_at_pos=getLeftChannel()[pos];
+                            tempbeats[tempbeats.size()-1].energy_at_pos=getLeftChannel(ORIGINAL_WAVE)[pos];
                             tempbeats[tempbeats.size()-1].min_amplitude=min_amplitude;
                             tempbeats[tempbeats.size()-1].max_amplitude=max_amplitude;
                             tempbeats[tempbeats.size()-1].min_pos=min_pos;
@@ -658,6 +663,8 @@ QMemArray<long> SoundManager::analyse_time_domain(const double treshold,
  */
 void SoundManager::resample(list<long>sortedPos,double new_to_oldBPM_ratio)
 {
+        fileManager->deleteAfterCurrent();
+        pushSoundBuffer(ORIGINAL_WAVE);
 #ifdef FLOAT_SAMPLES
         cout<<"SoundTouch compiled with FLOAT_SAMPLES\n";
 #else
@@ -696,11 +703,11 @@ void SoundManager::resample(list<long>sortedPos,double new_to_oldBPM_ratio)
 
 #ifdef FLOAT_SAMPLES
                 float * tmp_wave = new float[(endpos-startpos)*2];
-                exportMultiplexedBuffer(tmp_wave,startpos,endpos);
+                exportMultiplexedBuffer(tmp_wave,startpos,endpos,ORIGINAL_WAVE);
                 float * tmp_wave2 = new float[output_buffer_size*getChannels()];
 #else
                 short * tmp_wave = new short[(endpos-startpos)*2];
-                exportMultiplexedShortBuffer(tmp_wave,startpos,endpos);
+                exportMultiplexedShortBuffer(tmp_wave,startpos,endpos,ORIGINAL_WAVE);
                 short * tmp_wave2 = new short[output_buffer_size*getChannels()];
 #endif
 
@@ -710,9 +717,11 @@ void SoundManager::resample(list<long>sortedPos,double new_to_oldBPM_ratio)
 		do{
                         returned=st->receiveSamples(tmp_wave2,output_buffer_size);
 #ifdef FLOAT_SAMPLES
-                        outputWave=insertArray(outputWave,tmp_wave2,currentPos,returned);
+                        outputWave=SoundHolder::insertArray(outputWave,
+                                                                    tmp_wave2,currentPos,returned);
 #else
-                        outputWave=insertShortArray(outputWave,tmp_wave2,currentPos,returned);
+                        outputWave=SoundHolder::insertShortArray(outputWave,
+                                                                    tmp_wave2,currentPos,returned);
 #endif
                        currentPos+=returned;
                        if(true/*i%1000==0*/){
@@ -734,23 +743,24 @@ void SoundManager::resample(list<long>sortedPos,double new_to_oldBPM_ratio)
 	do{
 		returned=st->receiveSamples(tmp_wave2,output_buffer_size);
 #ifdef FLOAT_SAMPLES
-                outputWave=insertArray(outputWave,tmp_wave2,currentPos,returned);
+                outputWave=SoundHolder::insertArray(outputWave,
+                                                    tmp_wave2,currentPos,returned);
 #else
-                outputWave=insertShortArray(outputWave,tmp_wave2,currentPos,returned);
+                outputWave=SoundHolder::insertShortArray(outputWave,
+                                                    tmp_wave2,currentPos,returned);
 #endif
 
                 currentPos+=returned;
 	}while(returned!=0);
 #ifdef FLOAT_SAMPLES
-        importMultiplexedBuffer(outputWave,currentPos);
+        importMultiplexedBuffer(outputWave,currentPos,ORIGINAL_WAVE);
 #else
-        importMultiplexedShortBuffer(outputWave,currentPos);
+        importMultiplexedShortBuffer(outputWave,currentPos,ORIGINAL_WAVE);
 #endif
 
         zaparr(tmp_wave2);
         zaparr(outputWave);
-        fileManager->deleteAfterCurrent();
-        saveSoundBuffer();
+
         zapInstantEBuffer();
         emit(waveChanged());
 }
@@ -759,13 +769,13 @@ void SoundManager::resample(list<long>sortedPos,double new_to_oldBPM_ratio)
 
 
 /*!
-    \fn SoundManager::setFile(QString filename)
+    \fn SoundManager::loadFile(QString filename)
  */
 int SoundManager::loadFile()
 {
-
-        int result=loadBuffer(fileManager->getOriginalFilename());
-        saveSoundBuffer();
+        int result=SoundHolder::loadBuffer(fileManager->getOriginalFilename(),
+                                           ORIGINAL_WAVE);
+        zapInstantEBuffer();
         return result;
 }
 
@@ -798,24 +808,12 @@ double SoundManager::getMaxValue()
 }
 
 void SoundManager::crop(long start_sample, long end_sample){
-    assert(start_sample>=0 && end_sample<=getFrames());
-    float* croppedLeftChannel=new float[end_sample-start_sample];
-    float* croppedRightChannel=new float[end_sample-start_sample];
-    int count=0;
-    for (int i=start_sample;i<end_sample;i++){
-                croppedLeftChannel[count]=leftChannel[i];
-                croppedRightChannel[count]=rightChannel[i];
-                count++;
-    }
-    zaparr(rightChannel);
-    zaparr(leftChannel);
-    rightChannel=croppedRightChannel;
-    leftChannel=croppedLeftChannel;
-    setNbFrames(end_sample-start_sample);
-    croppedRightChannel=0;
-    croppedLeftChannel=0;
     fileManager->deleteAfterCurrent();
-    saveSoundBuffer();
+    pushSoundBuffer(ORIGINAL_WAVE);
+    assert(start_sample>=0 && end_sample<=getFrames());
+    SoundHolder::cropBuffers(start_sample,end_sample);
+    setNbFrames(end_sample-start_sample);
+    fileManager->deleteAfterCurrent();
     this->zapInstantEBuffer();
     //emit(waveChanged());
     emit(cropped(start_sample,end_sample));
@@ -834,9 +832,10 @@ void SoundManager::setFileManager(FileManager* _fm)
 /*!
     \fn SoundManager::saveSoundBuffer()
  */
-void SoundManager::saveSoundBuffer(){
+void SoundManager::pushSoundBuffer(bufferType type){
     QString temp=fileManager->getNextFilename();
-    saveSoundBufferTo(temp);
+    temp.prepend(QString::number(type)+"-");
+    saveSoundBufferTo(temp,type);
 }
 
 /*!
@@ -853,10 +852,10 @@ void SoundManager::saveSoundBuffer(long start_sample,long end_sample){
 /*!
     \fn SoundManager::saveSoundBuffer()
  */
-void SoundManager::saveSoundBufferTo(QString filename)
+void SoundManager::saveSoundBufferTo(QString filename,bufferType type)
 {
     /** \todo check here */
-    saveChunkToAs(filename,0,getFrames(),sfinfo.format);
+    saveChunkToAs(filename,0,getFrames(),sfinfo.format,0,type);
 }
 
 void SoundManager::saveChunkTo(QString filename,long start,long end,long start_at)
@@ -865,25 +864,13 @@ void SoundManager::saveChunkTo(QString filename,long start,long end,long start_a
     saveChunkToAs(filename,start,end,toBpsCode(32),start_at);
 }
 
-void SoundManager::saveChunkToAs(QString filename,long start,long end,int format,long start_at)
-{
-    std::cout<<"start writing "<<end-start<<" samples to: "<<filename<<" from: "<<start<<" to "<<end<<"\n";
-    SF_INFO tempsfinfo=sfinfo;
-    tempsfinfo.format=format;
-    SNDFILE* tmp_sndfile = sf_open (filename, SFM_RDWR, &tempsfinfo);
-    cout<<"sfseek: "<<sf_seek  (tmp_sndfile, (sf_count_t)start_at, SEEK_SET)<<"\n";
-    float* tmp_wave=exportMultiplexedBuffer(start,end);
-    sf_writef_float  (tmp_sndfile, tmp_wave,end-start);
-    sf_close(tmp_sndfile);
-    zaparr(tmp_wave);
-}
 
-
-bool SoundManager::previousSoundBuffer(){
+bool SoundManager::previousSoundBuffer(bufferType type){
     if(!fileManager->hasPrevious()) return FALSE;
     QString previous=fileManager->getPreviousFilename();
     std::cout<<"reverting to "<<previous<<"\n";
-    loadBuffer(previous);
+    SoundHolder::loadBuffer(previous, ORIGINAL_WAVE);
+    zapInstantEBuffer();
     return TRUE;
 }
 
@@ -901,7 +888,8 @@ bool SoundManager::nextSoundBuffer(){
     if(!fileManager->hasNext())return FALSE;
     QString next=fileManager->getNextFilename();
     std::cout<<"redoing "<<next<<"\n";
-    loadBuffer(next);
+    SoundHolder::loadBuffer(next,ORIGINAL_WAVE);
+    zapInstantEBuffer();
      return TRUE;
 }
 
@@ -914,9 +902,9 @@ int SoundManager::loadBuffer(QString path,long start_sample,long end_sample){
     sf_readf_float(tmp_sndfile, wavefile,(sf_count_t)(end_sample-start_sample));
     int count=0;
     for (int i=start_sample;i<end_sample;i++){
-            leftChannel[i]=wavefile[count];
-            rightChannel[i]=wavefile[count+1];
-            count+=sfinfo.channels;
+        getLeftChannel(ORIGINAL_WAVE)[i]=wavefile[count];
+        getRightChannel(ORIGINAL_WAVE)[i]=wavefile[count+1];
+        count+=sfinfo.channels;
     }
 
     zaparr(wavefile);
@@ -925,57 +913,8 @@ int SoundManager::loadBuffer(QString path,long start_sample,long end_sample){
 
 }
 
-int SoundManager::loadBuffer(QString path){
-    SNDFILE* tmp_sndfile= sf_open(path, SFM_READ, &sfinfo);
-    if (!tmp_sndfile) return 1;
-    zapInstantEBuffer();
-    sf_command(tmp_sndfile,SFC_CALC_SIGNAL_MAX,&maxValue,sizeof(double));
 
 
-    //std::cout<<maxValue;
-    channels=sfinfo.channels;
-    rate=sfinfo.samplerate;
-    setNbFrames(sfinfo.frames);
-
-    QProgressDialog progress("Loading File...",NULL,sfinfo.frames,NULL,"progress",TRUE);
-    progress.setMinimumDuration(2000);
-
-
-    if (leftChannel) zaparr(leftChannel);
-    if (rightChannel) zaparr(rightChannel);
-    leftChannel=new float[sfinfo.frames];
-    rightChannel=new float[sfinfo.frames];
-
-    float* wavefile=new float[sfinfo.frames*2/*sfinfo.channels*/];
-    sf_readf_float(tmp_sndfile, wavefile,(sf_count_t)sfinfo.frames);
-    //demux channels
-    int count=0;
-    for (int i=0;i<sfinfo.frames;i++){
-            leftChannel[i]=wavefile[count];
-            if(channels==2)
-                rightChannel[i]=wavefile[count+1];
-            else if(channels==1){
-                rightChannel[i]=wavefile[count];
-            }
-            count+=sfinfo.channels;
-            if(i%100000==0){
-                progress.setProgress(i);
-                progress.setLabelText("Loading File...(frame: "+QString::number(i)+")");
-            }
-    }
-    //end demux channels
-    progress.close();
-
-    zaparr(wavefile);
-    sf_close(tmp_sndfile);
-
-    _hasSound=TRUE;
-    zapInstantEBuffer();
-    if (channels==1) channels=2;
-    sfinfo.channels=2;
-    return 0;
-}
-
 /*!
     \fn SoundManager::saveChunksTo(QString,long*)
  */
@@ -1013,17 +952,11 @@ void SoundManager::applyPlugin(LADSPAEffect* effect,long start_sample, long end_
 
     //audio ports
 
-    //float* inputBufferLeft=&getLeftChannel()[start_sample];
-    //float* inputBufferRight=&getRightChannel()[start_sample];
+    float* inputBufferLeft=SoundHolder::getLeftChannel(BEFORE_LADSPA);
+    float* inputBufferRight=SoundHolder::getRightChannel(BEFORE_LADSPA);
 
-    float* inputBufferLeft=getLeftChannel();
-    float* inputBufferRight=getRightChannel();
-
-    //float* outputBufferLeft=new float[end_sample-start_sample];
-    //float* outputBufferRight=new float[end_sample-start_sample];
-
-    float* outputBufferLeft=new float[getFrames()];
-    float* outputBufferRight=new float[getFrames()];
+    float* outputBufferLeft=SoundHolder::getLeftChannel(AFTER_LADSPA);
+    float* outputBufferRight=SoundHolder::getRightChannel(AFTER_LADSPA);
 
     //end audio ports
 
@@ -1052,15 +985,13 @@ void SoundManager::applyPlugin(LADSPAEffect* effect,long start_sample, long end_
             }
             assert(processedSamples<=getFrames());
     }
-    this->importLeftBuffer(&outputBufferLeft[start_sample],start_sample,start_sample+processedSamples);
-    this->importRightBuffer(&outputBufferRight[start_sample],start_sample,start_sample+processedSamples);
-
-
-
-    saveSoundBuffer(start_sample,end_sample);
-
-    zaparr(outputBufferLeft);
-    zaparr(outputBufferRight);
+    if(hasEnvelope){
+        applyEnvelope();
+    }else{
+        this->zapInstantEBuffer();
+        //emit(waveChanged(start_sample,end_sample));  //should be..
+        emit(waveChanged()); //is ..
+    }
 }
 
 
@@ -1070,19 +1001,8 @@ void SoundManager::applyPlugin(LADSPAEffect* effect){
     emit(waveChanged());
 }
 
-void SoundManager::undoAndApplyPlugin(LADSPAEffect* effect){
-    previousSoundBuffer();
-    applyPlugin(effect);
-}
 
-void SoundManager::undoAndApplyPlugin(LADSPAEffect* effect,long start_sample,long end_sample){
-    assert(start_sample>=0 && end_sample<=getFrames());
-    previousSoundBuffer(start_sample,end_sample);
-    applyPlugin(effect,start_sample,end_sample);
-    this->zapInstantEBuffer();
-    //emit(waveChanged(start_sample,end_sample));  //should be..
-    emit(waveChanged()); //is ..
-}
+
 
 /*!
     \fn SoundManager::getEffects()
@@ -1096,27 +1016,7 @@ LADSPAEffects* SoundManager::getEffects()
 
 
 
-/*!
-    \fn SoundManager::insertShortArray(short*,short*,long,long)
- */
-short* SoundManager::insertShortArray(short* dest,short* src,long position,long size)
-{
-    for (int i=position*channels;i<(position+size)*channels;i++){
-        dest[i]=src[i-(position*channels)];
-    }
-    return dest;
-}
 
-/*!
-    \fn SoundManager::insertArray(float*,float*,long,long)
- */
-float* SoundManager::insertArray(float* dest,float* src,long position,long size)
-{
-    for (int i=position*channels;i<(position+size)*channels;i++){
-        dest[i]=src[i-(position*channels)];
-    }
-    return dest;
-}
 
 
 /*!
@@ -1124,6 +1024,7 @@ float* SoundManager::insertArray(float* dest,float* src,long position,long size)
  */
 void SoundManager::zapInstantEBuffer()
 {
+    cout<<"Zapping buffers\n";
     if(instant_buffer) zaparr(instant_buffer);
     if(hirestemp_subband_energies) zaparr(hirestemp_subband_energies);
     if(hiresfreq_subband_energies) zaparr(hiresfreq_subband_energies);
@@ -1140,7 +1041,8 @@ float** SoundManager::compute_subband_energies(int subband_number,
                                                                                                     int frames,int advance_frames,int padding,
                                                                                                     long start_sample,long end_sample,
                                                                                                     int startfreq, int endfreq,
-                                                                                                    float& fftMinima,float& fftMaxima)
+                                                                                                    float& fftMinima,float& fftMaxima,
+                                                                                                    bufferType type)
 {
 
     assert(start_sample>=0 && end_sample<=getFrames());
@@ -1148,8 +1050,8 @@ float** SoundManager::compute_subband_energies(int subband_number,
     progress.setMinimumDuration(2000);
 
     //convert start/end frequency to fft index
-    float start_index=(startfreq*frames)/44100;
-    float end_index=(endfreq*frames)/44100;
+    float start_index=(startfreq*frames)/getRate();
+    float end_index=(endfreq*frames)/getRate();
     //end convert start/end frequency to fft index
 
 
@@ -1159,11 +1061,11 @@ float** SoundManager::compute_subband_energies(int subband_number,
     float* lchannel=0;
     float* rchannel=0;
     if(derivateSignal){
-        lchannel=exportDerivatedLeftBuffer(start_sample,end_sample);
-        rchannel=exportDerivatedRightBuffer(start_sample,end_sample);
+        lchannel=exportDerivatedLeftBuffer(start_sample,end_sample,type);
+        rchannel=exportDerivatedRightBuffer(start_sample,end_sample,type);
     }else{
-        lchannel=&getLeftChannel()[start_sample];
-        rchannel=&getRightChannel()[start_sample];
+        lchannel=&getLeftChannel(type)[start_sample];
+        rchannel=&getRightChannel(type)[start_sample];
     }
 
 
@@ -1187,7 +1089,8 @@ float** SoundManager::compute_subband_energies(int subband_number,
     for (int i=start_sample;i<end_sample-frames;i+=advance_frames){
             //fill in and out buffers
             if(windowMode==WINDOW_GAUSS){
-                float std_dev=MyMath::standard_deviation(&getLeftChannel()[i],advance_frames);
+                float std_dev=
+                        MyMath::standard_deviation(&getLeftChannel(type)[i],advance_frames);
                 MyMath::gaussian_window(gaussian,advance_frames,MyMath::linear_regression(0,1,2,8,std_dev));
             }
             for (int i2=i;i2<i+frames;i2++){
@@ -1333,7 +1236,8 @@ float** SoundManager::getHiresTempSubbandEnergies()
             compute_subband_energies(hirestemp_nbbands,hirestemp_fft_width,hirestemp_fft_advance,
                                                                 hirestemp_padding,0,frames,
                                                                 hirestemp_startfreq,hirestemp_endfreq,
-                                                                hirestemp_fftMinima,hirestemp_fftMaxima);
+                                                                hirestemp_fftMinima,hirestemp_fftMaxima,
+                                                                ORIGINAL_WAVE);
     return hirestemp_subband_energies;
 }
 
@@ -1344,7 +1248,7 @@ float** SoundManager::getHiresFreqSubbandEnergies()
             compute_subband_energies(hiresfreq_nbbands,hiresfreq_fft_width,hiresfreq_fft_advance,
                                                                      hiresfreq_padding,0,frames,
                                                                      hiresfreq_startfreq,hiresfreq_endfreq,
-                                                                    hiresfreq_fftMinima,hiresfreq_fftMaxima);
+                                                                    hiresfreq_fftMinima,hiresfreq_fftMaxima,FOR_OUTPUT);
     return hiresfreq_subband_energies;
 }
 
@@ -1373,15 +1277,19 @@ void SoundManager::recompute_subband_energies(){
     if(hirestemp_subband_energies) zaparr(hirestemp_subband_energies);
     hirestemp_subband_energies=
                         compute_subband_energies(hirestemp_nbbands,hirestemp_fft_width,
-                                                                                hirestemp_fft_advance,hirestemp_padding,0,getFrames(),
+                                                                                hirestemp_fft_advance,hirestemp_padding,
+                                                                                0,getFrames(),
                                                                                 hirestemp_startfreq,hirestemp_endfreq,
-                                                                                hirestemp_fftMinima,hirestemp_fftMaxima);
+                                                                                hirestemp_fftMinima,hirestemp_fftMaxima,
+                                                                                ORIGINAL_WAVE);
     if(hiresfreq_subband_energies) zaparr(hiresfreq_subband_energies);
     hiresfreq_subband_energies=
                         compute_subband_energies(hiresfreq_nbbands,hiresfreq_fft_width,
-                                                                              hiresfreq_fft_advance,hiresfreq_padding,0,getFrames(),
+                                                                              hiresfreq_fft_advance,hiresfreq_padding,
+                                                                                0,getFrames(),
                                                                               hiresfreq_startfreq,hiresfreq_endfreq,
-                                                                                hiresfreq_fftMinima,hiresfreq_fftMaxima);
+                                                                                hiresfreq_fftMinima,hiresfreq_fftMaxima,
+                                                                                FOR_OUTPUT);
 }
 
 
@@ -1446,7 +1354,7 @@ void SoundManager::addPostProcessEffect(CustomEffect* ppe)
  */
 void SoundManager::getLeftChannelBand(float* data,long start_sample, long end_sample,int start_band_freq, int end_band_freq, bool invert)
 {
-    getBand(getLeftChannel(),data,start_sample,end_sample, start_band_freq, end_band_freq, invert);
+    getBand(getLeftChannel(FOR_OUTPUT),data,start_sample,end_sample, start_band_freq, end_band_freq, invert);
 
 }
 
@@ -1456,7 +1364,7 @@ void SoundManager::getLeftChannelBand(float* data,long start_sample, long end_sa
  */
 void SoundManager::getRightChannelBand(float* data,long start_sample, long end_sample,int start_band_freq, int end_band_freq, bool invert)
 {
-    getBand(getRightChannel(),data,start_sample,end_sample, start_band_freq, end_band_freq, invert);
+    getBand(getRightChannel(FOR_OUTPUT),data,start_sample,end_sample, start_band_freq, end_band_freq, invert);
 }
 
 
@@ -1640,34 +1548,35 @@ QMemArray <SoundManager::beat> SoundManager::findPreciseBeat(QMemArray<beat> inp
                     pos=getFrames();
                 }else{
 		    if(search_distance==0){
-		    	temp_abs_en_left=fabs(getLeftChannel()[j]);
-			temp_en_left+=getLeftChannel()[j];
-			temp_abs_en_right=fabs(getLeftChannel()[j+1]);
-			temp_en_right+=getLeftChannel()[j+1];
+                        temp_abs_en_left=fabs(getLeftChannel(ORIGINAL_WAVE)[j]);
+                        temp_en_left+=getLeftChannel(ORIGINAL_WAVE)[j];
+                        temp_abs_en_right=fabs(getLeftChannel(ORIGINAL_WAVE)[j+1]);
+                        temp_en_right+=getLeftChannel(ORIGINAL_WAVE)[j+1];
 			left_energy=temp_abs_en_left;
                         right_energy=temp_abs_en_right;
 		    }else{
                         if(j==start_pos){
                             //first run, compute all
                             for (int k=j-search_distance;k<j;k++){
-                                    temp_abs_en_left+=fabs(getLeftChannel()[k]);
-                                    temp_en_left+=getLeftChannel()[k];
+                                temp_abs_en_left+=fabs(getLeftChannel(ORIGINAL_WAVE)[k]);
+                                temp_en_left+=getLeftChannel(ORIGINAL_WAVE)[k];
                             }
                             for (int k=j;k<j+search_distance;k++){
-                                    temp_abs_en_right+=fabs(getLeftChannel()[k]);
-                                    temp_en_right+=getLeftChannel()[k];
+                                temp_abs_en_right+=fabs(getLeftChannel(ORIGINAL_WAVE)[k]);
+                                temp_en_right+=getLeftChannel(ORIGINAL_WAVE)[k];
                             }
                         }else{
                             //add/substaract differences
-                            temp_abs_en_left=temp_abs_en_left-fabs(getLeftChannel()[j])+
-                                                                                                fabs(getLeftChannel()[j-search_distance]);
-                            temp_en_left=temp_en_left-getLeftChannel()[j]+
-                                                                                                getLeftChannel()[j-search_distance];
+                            temp_abs_en_left=temp_abs_en_left-fabs(getLeftChannel(ORIGINAL_WAVE)[j])+
+                                    fabs(getLeftChannel(ORIGINAL_WAVE)[j-search_distance]);
+                            temp_en_left=temp_en_left-getLeftChannel(ORIGINAL_WAVE)[j]+
+                                    getLeftChannel(ORIGINAL_WAVE)[j-search_distance];
 
-                            temp_abs_en_right=temp_abs_en_right-fabs(getLeftChannel()[j+search_distance])+
-                                                                                                fabs(getLeftChannel()[j]);
-                            temp_en_right=temp_en_right-getLeftChannel()[j+search_distance]+
-                                                                                                getLeftChannel()[j];
+                            temp_abs_en_right=
+                                    temp_abs_en_right-fabs(getLeftChannel(ORIGINAL_WAVE)[j+search_distance])+
+                                    fabs(getLeftChannel(ORIGINAL_WAVE)[j]);
+                            temp_en_right=temp_en_right-getLeftChannel(ORIGINAL_WAVE)[j+search_distance]+
+                                    getLeftChannel(ORIGINAL_WAVE)[j];
                         }
 		    }
                     if(temp_abs_en_left<=distance_to_min_conf*distance_to_min){
@@ -1697,7 +1606,7 @@ QMemArray <SoundManager::beat> SoundManager::findPreciseBeat(QMemArray<beat> inp
         tempbeats.resize(tempbeats.size()+1);
         tempbeats[tempbeats.size()-1]=input[i];
         tempbeats[tempbeats.size()-1].sample_pos=pos;
-        tempbeats[tempbeats.size()-1].energy_at_pos=fabs(getLeftChannel()[pos]);
+        tempbeats[tempbeats.size()-1].energy_at_pos=fabs(getLeftChannel(ORIGINAL_WAVE)[pos]);
         tempbeats[tempbeats.size()-1].left_half_energy=left_energy;
         tempbeats[tempbeats.size()-1].right_half_energy=right_energy;
     }
@@ -1745,8 +1654,8 @@ void SoundManager::updateMaxAmplitudes(QMemArray<beat> beatlines, int search_dis
         int search_amplitude_end=pos+search_distance;
         if(search_amplitude_end>getFrames()) search_amplitude_end=getFrames();
         for (int j=pos;j<search_amplitude_end;j++){
-            if (fabs(getLeftChannel()[j])>max_amplitude){
-                max_amplitude=fabs(getLeftChannel()[j]);
+            if (fabs(getLeftChannel(ORIGINAL_WAVE)[j])>max_amplitude){
+                max_amplitude=fabs(getLeftChannel(ORIGINAL_WAVE)[j]);
             }
         }
         beatlines[i].max_amplitude=max_amplitude;
@@ -1768,3 +1677,125 @@ QMemArray<SoundManager::beat> SoundManager::removeRedundantBeatlines(QMemArray<b
     }
     return output;
 }
+
+
+/*!
+    \fn SoundManager::applyEnvelope()
+ */
+void SoundManager::applyEnvelope()
+{
+    if(hasEnvelope){
+        float* inputBufferLeft=SoundHolder::getLeftChannel(BEFORE_ENVELOPE);
+        float* inputBufferRight=SoundHolder::getRightChannel(BEFORE_ENVELOPE);
+        float* outputBufferLeft=SoundHolder::getLeftChannel(AFTER_ENVELOPE);
+        float* outputBufferRight=SoundHolder::getRightChannel(AFTER_ENVELOPE);
+        if(!envelopeData || !envelopeArray || lockedBeatLines.count()==0 || !envelopeData->isEnabled()){
+                std::memcpy(outputBufferLeft,inputBufferLeft,sizeof(long)*getFrames());
+                std::memcpy(outputBufferRight,inputBufferRight,sizeof(long)*getFrames());
+        }else{
+            cout<<"Applying Envelope: "<<envelopeData->toString()<<endl;
+            cout<<"lockedBeatLines.count(): "<<lockedBeatLines.count()<<endl;
+            long applyNbFrames=(envelopeData->env_duration/1000.0)*float(getRate());
+            long ahd_duration=
+                    ((envelopeData->attack+
+                    envelopeData->hold+
+                    envelopeData->decay)*envelopeData->env_duration/1000.0)*float(getRate());
+            long r_duration=(envelopeData->release*envelopeData->env_duration/1000.0)*float(getRate());
+            long s_duration=applyNbFrames-r_duration-ahd_duration;
+            for (long j=0;j<lockedBeatLines.count();j++){
+                long end=j<lockedBeatLines.count()-1?lockedBeatLines[j+1]:getFrames();
+                for (long i=lockedBeatLines[j];i<end;i++){
+                    if(envelopeData->env_mode!=EnvelopeData::FIT_TO_SAMPLES &&
+                    i-lockedBeatLines[j]<applyNbFrames){
+                        outputBufferLeft[i]=inputBufferLeft[i]*envelopeArray[i-lockedBeatLines[j]];
+                        outputBufferRight[i]=inputBufferRight[i]*envelopeArray[i-lockedBeatLines[j]];
+                    }else if(envelopeData->env_mode==EnvelopeData::FIT_TO_SAMPLES){
+                        if(i-lockedBeatLines[j]<=ahd_duration){
+                            outputBufferLeft[i]=inputBufferLeft[i]*envelopeArray[i-lockedBeatLines[j]];
+                            outputBufferRight[i]=inputBufferRight[i]*envelopeArray[i-lockedBeatLines[j]];
+                        }else if(i-lockedBeatLines[j]>ahd_duration &&i<end-r_duration){
+                            //apply sustain
+                            outputBufferLeft[i]=inputBufferLeft[i]*envelopeData->sustain;
+                            outputBufferRight[i]=inputBufferRight[i]*envelopeData->sustain;
+                        }else{
+                            //apply release
+                            outputBufferLeft[i]=inputBufferLeft[i]*
+                                    envelopeArray[applyNbFrames-(end-i)];
+                            outputBufferRight[i]=inputBufferRight[i]*
+                                    envelopeArray[applyNbFrames-(end-i)];
+                        }
+                    }else{
+                        if(envelopeData->env_mode!=EnvelopeData::FIT_TO_DURATION_CONTINUE){
+                            outputBufferLeft[i]=inputBufferLeft[i];
+                            outputBufferRight[i]=inputBufferRight[i];
+                        }else{ //EnvelopeData::FIT_TO_DURATION_CONTINUE
+                            outputBufferLeft[i]=inputBufferLeft[i]*envelopeArray[applyNbFrames-1];
+                            outputBufferRight[i]=inputBufferRight[i]*envelopeArray[applyNbFrames-1];
+                        }
+                    }
+                }
+            }
+        }
+    }
+    cout<<"Envelope applied\n";
+    this->zapInstantEBuffer();
+    //emit(waveChanged(start_sample,end_sample));  //should be..
+    emit(waveChanged()); //is ..
+}
+
+
+/*!
+    \fn SoundManager::lockedBeatLinesChanged(QValueList<long> beatlines)
+ */
+void SoundManager::lockedBeatLinesChanged(QValueList<long> beatlines)
+{
+    lockedBeatLines=beatlines;
+    applyEnvelope();
+}
+
+
+/*!
+    \fn SoundManager::beatLinesChanged(QValueList<long> beatlines)
+ */
+void SoundManager::beatLinesChanged(QValueList<long> beatlines)
+{
+    beatLines=beatlines;
+}
+
+
+/*!
+    \fn SoundManager::envelopeChanged(EnvelopeData* envData)
+ */
+void SoundManager::envelopeChanged(EnvelopeData* envData)
+{
+    //compute the envelope
+    if(envData){
+        envelopeData=envData;
+        long applyNbFrames=(envelopeData->env_duration/1000.0)*float(getRate());
+        if(envelopeArray) zaparr(envelopeArray);
+        envelopeArray=new float[applyNbFrames];
+        for (int i=0;i<applyNbFrames;i++){
+            envelopeArray[i]=envelopeData->getEnvAt(float(i)/float(applyNbFrames),
+                                            100.0/float(applyNbFrames));
+        }
+        applyEnvelope();
+    }
+}
+
+
+/*!
+    \fn SoundManager::getHasLADSPA()
+ */
+bool SoundManager::getHasLADSPA()
+{
+    return hasLADSPA;
+}
+
+
+/*!
+    \fn SoundManager::getHasEnvelope()
+ */
+bool SoundManager::getHasEnvelope()
+{
+    return hasEnvelope;
+}
